<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-mots?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// M
	'mots_description' => 'Terfwoorden en groepen van trefwoorden',
	'mots_slogan' => 'Beheer van trefwoorden en groepen van trefwoorden in SPIP'
);

?>
